==> movisens_flutter-1.0.0.tar.gz: lib/movisens_characteristic.dart <==
/*
 * Copyright 2022 Copenhagen Center for Health Technology (CACHET) at the
 * Technical University of Denmark (DTU).
 * Use of this source code is governed by a MIT-style license that can be
 * found in the LICENSE file.
 */
part of movisens_flutter;

/// Enumerated list of Bluetooth characteristics offered on Movisens devices.
enum MovisensBluetoothCharacteristics {
  light,
  lightBuffered,
  lightRGB,
  lightRGBBuffered,
  lightRGBWaiting,
  lightWaiting,
  sensorTemperature,
  sensorTemperatureBuffered,
  sensorTemperatureWaiting,
  edaSclMean,
  edaSclMeanBuffered,
  edaSclMeanWaiting,
  hrMean,
  hrMeanBuffered,
  hrMeanWaiting,
  hrvIsValid,
  hrvIsValidBuffered,
  hrvIsValidWaiting,
  rmssd,
  rmssdBuffered,
  rmssdWaiting,
  tapMarker,
  batteryLevelBuffered,
  batteryLevelWaiting,
  charging,
  chargingBuffered,
  chargingWaiting,
  ageFloat,
  sensorLocation,
  bodyPosition,
  bodyPositionBuffered,
  bodyPositionWaiting,
  inclination,
  inclinationBuffered,
  inclinationWaiting,
  met,
  metBuffered,
  metLevel,
  metLevelBuffered,
  metLevelWaiting,
  metWaiting,
  movementAcceleration,
  movementAccelerationBuffered,
  movementAccelerationWaiting,
  steps,
  stepsBuffered,
  stepsWaiting,
  respiratoryMovement,
  activatedBufferedCharacteristics,
  commandResult,
  currentTimeMs,
  customData,
  dataAvailable,
  deleteData,
  measurementEnabled,
  measurementStartTime,
  measurementStatus,
  saveEnergy,
  sendBufferedData,
  startMeasurement,
  status,
  storageLevel,
  timeZoneId,
  timeZoneOffset,
  skinTemperature,
  skinTemperature1sBuffered,
  skinTemperatureBuffered,
  skinTemperatureWaiting
}

==> movisens_flutter-3.1.1.tar.gz: lib/movisens_characteristic.dart <==
/*
 * Copyright 2022 Copenhagen Center for Health Technology (CACHET) at the
 * Technical University of Denmark (DTU).
 * Use of this source code is governed by a MIT-style license that can be
 * found in the LICENSE file.
 */
part of movisens_flutter;

/// Enumerated list of Bluetooth characteristics offered on Movisens devices.
enum MovisensBluetoothCharacteristics {
  light,
  lightBuffered,
  lightRGB,
  lightRGBBuffered,
  lightRGBWaiting,
  lightWaiting,
  sensorTemperature,
  sensorTemperatureBuffered,
  sensorTemperatureWaiting,
  edaSclMean,
  edaSclMeanBuffered,
  edaSclMeanWaiting,
  hrMean,
  hrMeanBuffered,
  hrMeanWaiting,
  hrvIsValid,
  hrvIsValidBuffered,
  hrvIsValidWaiting,
  rmssd,
  rmssdBuffered,
  rmssdWaiting,
  tapMarker,
  batteryLevelBuffered,
  batteryLevelWaiting,
  charging,
  chargingBuffered,
  chargingWaiting,
  ageFloat,
  sensorLocation,
  bodyPosition,
  bodyPositionBuffered,
  bodyPositionWaiting,
  inclination,
  inclinationBuffered,
  inclinationWaiting,
  met,
  metBuffered,
  metLevel,
  metLevelBuffered,
  metLevelWaiting,
  metWaiting,
  movementAcceleration,
  movementAccelerationBuffered,
  movementAccelerationWaiting,
  steps,
  stepsBuffered,
  stepsWaiting,
  respiratoryMovement,
  activatedBufferedCharacteristics,
  commandResult,
  currentTimeMs,
  customData,
  dataAvailable,
  deleteData,
  measurementEnabled,
  measurementStartTime,
  measurementStatus,
  saveEnergy,
  sendBufferedData,
  startMeasurement,
  status,
  storageLevel,
  timeZoneId,
  timeZoneOffset,
  skinTemperature,
  skinTemperature1sBuffered,
  skinTemperatureBuffered,
  skinTemperatureWaiting,

  // General bluetooth 4.0 characteristics:
  batteryLevel,
  firmwareRevisionString,
  manufacturerNameString,
  modelNumberString,
  serialNumberString,
  heartRateMeasurement,
  gender,
  height,
  weight,
}
